import type { ArticleStore } from "../domain/articleStore";
import { useCallback, useEffect } from "react";
import { Article } from "article/domain/articleEntity";
import { GetArticleUseCase } from "article/useCases/getArticleUseCase";
import { FetchArticleUseCase } from "article/useCases/fetchArticleUseCase";
import { useParams } from "react-router-dom";

function useArticleViewModel(
  store: ArticleStore,
  fetchArticleUseCase: FetchArticleUseCase,
  getArticleUseCase: GetArticleUseCase,
) {
  const { id } = useParams();

  const getArticle = useCallback(
    () => {
      getArticleUseCase.call(id ?? '').catch((_) => fetchArticleUseCase.call(id ?? ''));
      console.log(id);
    },
    [id]
  );

  useEffect(getArticle, []);

  return {
    article: store.currentArticle,
    shouldShowLoading: store.isLoading,
    hasError: store.hasError,
  };
}

export { useArticleViewModel };
