import { Article } from "article/domain/articleEntity";
import type { ArticleStore } from "../domain/articleStore";

class GetArticleUseCase {
  /* ------------------------------ Dependencies ------------------------------ */
  _store: ArticleStore;
  /* -------------------------------------------------------------------------- */
  constructor(
    store: ArticleStore,
  ) {
    this._store = store;
  }
  /* ----------------------------- Implementation ----------------------------- */
  async call(id: string): Promise<Article> {
    const storedArticle = this._store.getArticle(id);
    if (storedArticle != null) {
      this._store.setArticle(storedArticle);
      return storedArticle;
    }
    throw new Error('Article not found');
  }
  /* -------------------------------------------------------------------------- */
}


const getArticleUseCase = async (
  getArticle: ArticleStore["getArticle"],
  setArticle: ArticleStore["setArticle"],
  id: Article["id"]
): Promise<Article | null> => {
  const article = await getArticle(id);
  if (article) {
    await setArticle(article);
  }
  return article;
};

export { GetArticleUseCase };
export { getArticleUseCase };
